Package: StableEstim
Type: Package
Title: Estimate the Four Parameters of Stable Laws using Different
        Methods
Version: 2.4
Depends: R (>= 2.10.0)
Imports: stats, utils, graphics, numDeriv, fBasics, MASS, methods,
        stabledist, Rdpack
Suggests: testthat (>= 1.0.0), xtable
Authors@R: c( person(given = "Tarak", family = "Kharrat",
                     role = c("aut"), 
                     email = "tarak@realanalytics.co.uk",
		     comment = c(ORCID = "0000-0001-9399-6174")),
              person(given = c("Georgi", "N."), family = "Boshnakov", 
                     role = c("aut", "cre"), 
                     email = "georgi.boshnakov@manchester.ac.uk",
		     comment = c(ORCID = "0000-0003-2839-346X")) )
Description: Estimate the four parameters of stable laws using maximum
             likelihood method, generalised method of moments with
             finite and continuum number of points, iterative
             Koutrouvelis regression and Kogon-McCulloch method.  The
             asymptotic properties of the estimators (covariance
             matrix, confidence intervals) are also provided.
License: GPL (>= 2)
RdMacros: Rdpack
URL: https://geobosh.github.io/StableEstim/ (doc),
        https://CRAN.R-project.org/package=StableEstim
BugReports: https://github.com/GeoBosh/StableEstim/issues
Collate: cte.R ExternalPackageInterface.R ToolsFct.R Interpolation.R
        RegularInverse.R stableCF.R CFbasedMoment.R WeightingMatrix.R
        eCFfirstZero.R tSchemes.R MultiDimIntegral.R InitialGuess.R
        KoutParamsEstim.R MLParamsEstim.R GMMParamsEstim.R
        CgmmParamsEstim.R OutputFileManip.R CheckPoint.R BestT_Class.R
        Estim_Class.R Estim.R Simulation.R BestT.R
NeedsCompilation: no
Packaged: 2025-12-09 12:21:53 UTC; georgi
Author: Tarak Kharrat [aut] (ORCID: <https://orcid.org/0000-0001-9399-6174>),
  Georgi N. Boshnakov [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2839-346X>)
Maintainer: Georgi N. Boshnakov <georgi.boshnakov@manchester.ac.uk>
Repository: CRAN
Date/Publication: 2025-12-09 12:50:02 UTC
Built: R 4.6.0; ; 2026-04-27 08:40:56 UTC; unix
