#import(methods, Matrix)
import(methods)

importFrom(stats, dnorm, pnorm, qnorm, rnorm,
	          runif, integrate, uniroot, optimize)
importFrom(graphics, plot)
importFrom(stats, dunif, lm, nlminb, optim, sd, var)
importFrom(utils, read.csv, read.table, toLatex, write.table, packageVersion)

importFrom(stabledist, dstable, rstable, pstable, qstable)
#importFrom(fBasics, .qStableFit)
importFrom(numDeriv, jacobian)
importFrom(MASS, lm.gls)
#importFrom(testthat, expectation, expect_that, expect_equal)   # in Suggests 2025-12-08
#importFrom(xtable, xtable, "align<-", "digits<-", "display<-") # in Suggests 2025-12-08
importFrom(Rdpack, reprompt)
    
exportClass(Estim)
exportClass(Best_t)

exportMethods("+", show, initialize)

export(
    getTime_,
    PrintDuration,
    ComputeDuration,
    PrintEstimatedRemainingTime,
    expect_almost_equal,
    get.StatFcts,
    get.abMat,
    ComplexCF,
    jacobianComplexCF,
    ComputeFirstRootRealeCF,
    IntegrateRandomVectorsProduct,
    RegularisedSol,
    sampleComplexCFMoment,
    sampleRealCFMoment,
    Estim,
    McCullochParametersEstim,
    IGParametersEstim,
    KoutParametersEstim,
    GMMParametersEstim,
    CgmmParametersEstim,
    MLParametersEstim,
    Estim_Simulation,
    ComputeStatObjectFromFiles,
    TexSummary,
    ConcatFiles,
    ComputeBest_t,
    ComputeBest_tau,

    ## re-exports
    rstable
    )
